grib2io.tables.section4_discipline1 API documentation

# grib2io.tables.section4_discipline1

View Source

     1table_4_2_1_0  = {
     2'0':['Flash Flood Guidance (Encoded as an accumulation over a floating subinterval of time between the reference time and valid time)','kg m-2','FFLDG'],
     3'1':['Flash Flood Runoff (Encoded as an accumulation over a floating subinterval of time)','kg m-2','FFLDRO'],
     4'2':['Remotely Sensed Snow Cover','See Table 4.215','RSSC'],
     5'3':['Elevation of Snow Covered Terrain','See Table 4.216','ESCT'],
     6'4':['Snow Water Equivalent Percent of Normal','%','SWEPON'],
     7'5':['Baseflow-Groundwater Runoff','kg m-2','BGRUN'],
     8'6':['Storm Surface Runoff','kg m-2','SSRUN'],
     9'7':['Discharge from Rivers or Streams','m3 s-1','DISRS'],
    10'8':['Group Water Upper Storage','kg m-2','GWUPS'],
    11'9':['Group Water Lower Storage','kg m-2','GWLOWS'],
    12'10':['Side Flow into River Channel','m3 s-1 m-1','SFLORC'],
    13'11':['River Storage of Water','m3','RVERSW'],
    14'12':['Flood Plain Storage of Water','m3','FLDPSW'],
    15'13':['Depth of Water on Soil Surface','kg m-2','DEPWSS'],
    16'14':['Upstream Accumulated Precipitation','kg m-2','UPAPCP'],
    17'15':['Upstream Accumulated Snow Melt','kg m-2','UPASM'],
    18'16':['Percolation Rate','kg m-2 s-1','PERRATE'],
    19'17-191':['Reserved','unknown','unknown'],
    20'192-254':['Reserved for Local Use','unknown','unknown'],
    21'192':['Baseflow-Groundwater Runoff','kg m-2','BGRUN'],
    22'193':['Storm Surface Runoff','kg m-2','SSRUN'],
    23'255':['Missing','unknown','unknown'],
    24}
    25table_4_2_1_1  = {
    26'0':['Conditional percent precipitation amount fractile for an overall period (encoded as an accumulation)','kg m-2','CPPOP'],
    27'1':['Percent Precipitation in a sub-period of an overall period (encoded as a percent accumulation over the sub-period)','%','PPOSP'],
    28'2':['Probability of 0.01 inch of precipitation (POP)','%','POP'],
    29'3-191':['Reserved','unknown','unknown'],
    30'192-254':['Reserved for Local Use','unknown','unknown'],
    31'192':['Probability of Freezing Precipitation','%','CPOZP'],
    32'193':['Percent of Frozen Precipitation','%','CPOFP'],
    33'194':['Probability of precipitation exceeding flash flood guidance values','%','PPFFG'],
    34'195':['Probability of Wetting Rain, exceeding in 0.10" in a given time period','%','CWR'],
    35'255':['Missing','unknown','unknown'],
    36}
    37table_4_2_1_2  = {
    38'0':['Water Depth','m','WDPTHIL'],
    39'1':['Water Temperature','K','WTMPIL'],
    40'2':['Water Fraction','Proportion','WFRACT'],
    41'3':['Sediment Thickness','m','SEDTK'],
    42'4':['Sediment Temperature','K','SEDTMP'],
    43'5':['Ice Thickness','m','ICTKIL'],
    44'6':['Ice Temperature','K','ICETIL'],
    45'7':['Ice Cover','Proportion','ICECIL'],
    46'8':['Land Cover (0=water, 1=land)','Proportion','LANDIL'],
    47'9':['Shape Factor with Respect to Salinity Profile','unknown','SFSAL'],
    48'10':['Shape Factor with Respect to Temperature Profile in Thermocline','unknown','SFTMP'],
    49'11':['Attenuation Coefficient of Water with Respect to Solar Radiation','m-1','ACWSR'],
    50'12':['Salinity','kg kg-1','SALTIL'],
    51'13':['Cross Sectional Area of Flow in Channel','m2','CSAFC'],
    52'14':['Snow temperature','K','LNDSNOWT'],
    53'15-191':['Reserved','unknown','unknown'],
    54'192-254':['Reserved for Local Use','unknown','unknown'],
    55'255':['Missing','unknown','unknown'],
    56}